@@ -389,10 +389,11 @@ int main(int argc, char **argv)
 			/* falls through */
 		case 'u':  /* --user <username>|<uid> */
 		{
+			char dummy[2];
 			p = optarg;
 			tmp = strsep(&p, ":");
 			changeuser = xstrdup(tmp);
-			if (sscanf(tmp, "%d", &tid) != 1)
+			if (sscanf(tmp, "%d%1s", &tid, dummy) != 1)
 				pw = getpwnam(tmp);
 			else
 				pw = getpwuid((uid_t)tid);
@@ -413,7 +414,7 @@ int main(int argc, char **argv)
 
 			if (p) {
 				tmp = strsep (&p, ":");
-				if (sscanf(tmp, "%d", &tid) != 1)
+				if (sscanf(tmp, "%d%1s", &tid, dummy) != 1)
 					gr = getgrnam(tmp);
 				else
 					gr = getgrgid((gid_t) tid);
@@ -628,7 +629,7 @@ int main(int argc, char **argv)
 	}
 	if (start && !exists(exec_file)) {
 		eerror("%s: %s does not exist", applet,
-		    *exec_file ? exec_file : exec);
+		    exec_file ? exec_file : exec);
 		free(exec_file);
 		exit(EXIT_FAILURE);
 	}
@@ -669,7 +670,7 @@ int main(int argc, char **argv)
 					nav[len++] = p;
 				for (i = 0; i < opt; i++)
 					nav[i + len] = argv[i];
-				nav[i + len] = '\0';
+				nav[i + len] = NULL;
 			}
 		}
 	}
@@ -863,8 +864,8 @@ int main(int argc, char **argv)
 
 		TAILQ_FOREACH(env, env_list, entries) {
 			if ((strncmp(env->value, "RC_", 3) == 0 &&
-				strncmp(env->value, "RC_SERVICE=", 10) != 0 &&
-				strncmp(env->value, "RC_SVCNAME=", 10) != 0) ||
+				strncmp(env->value, "RC_SERVICE=", 11) != 0 &&
+				strncmp(env->value, "RC_SVCNAME=", 11) != 0) ||
 				strncmp(env->value, "SSD_NICELEVEL=", 14) == 0 ||
 				strncmp(env->value, "SSD_IONICELEVEL=", 16) == 0)
 			{
